@@ -21,23 +21,21 @@
 
    Author: Ettore Perazzoli <ettore@gnu.org> */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
+#include "gnome-vfs-inet-connection.h"
 
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <unistd.h>
-#include <string.h>
-
-#include <netdb.h>
-extern int h_errno;
-
-#include <glib.h>
-
-#include "gnome-vfs.h"
 #include "gnome-vfs-private.h"
+#include "gnome-vfs.h"
+#include <errno.h>
+#include <glib.h>
+#include <netdb.h>
+#include <netinet/in.h>
+#include <string.h>
+#include <sys/socket.h>
+#include <sys/types.h>
+#include <unistd.h>
+
+extern int h_errno;
 
 
 struct GnomeVFSInetConnection {
@@ -66,18 +64,21 @@ gnome_vfs_inet_connection_create (GnomeVFSInetConnection **connection_return,
 		return gnome_vfs_result_from_errno ();
 
 	host_info = gethostbyname (host_name);
-	if (gnome_vfs_cancellation_check (cancellation))
+	if (gnome_vfs_cancellation_check (cancellation)) {
 		return GNOME_VFS_ERROR_CANCELLED;
+	}
 
-	if (host_info == NULL)
+	if (host_info == NULL) {
 		return gnome_vfs_result_from_h_errno ();
+	}
 
 	addr.sin_family = host_info->h_addrtype;
 	addr.sin_addr = * (struct in_addr *) host_info->h_addr;
 	addr.sin_port = htons (host_port);
 
-	if (connect (sock, (struct sockaddr *) &addr, sizeof (addr)) < 0)
+	if (connect (sock, (struct sockaddr *) &addr, sizeof (addr)) < 0) {
 		return gnome_vfs_result_from_errno ();
+	}
 
 	new = g_new (GnomeVFSInetConnection, 1);
 	memcpy (&new->addr, &addr, sizeof (addr));
@@ -91,7 +92,7 @@ gnome_vfs_inet_connection_create (GnomeVFSInetConnection **connection_return,
 
 void
 gnome_vfs_inet_connection_destroy (GnomeVFSInetConnection *connection,
-				   GnomeVFSCancellation *cancellation)
+				   GnomeVFSCancellation   *cancellation)
 {
 	g_return_if_fail (connection != NULL);
 
@@ -99,6 +100,12 @@ gnome_vfs_inet_connection_destroy (GnomeVFSInetConnection *connection,
 	g_free (connection);
 }
 
+static void
+gnome_vfs_inet_connection_close (GnomeVFSInetConnection *connection)
+{
+	gnome_vfs_inet_connection_destroy (connection, NULL);
+}
+
 GnomeVFSIOBuf *
 gnome_vfs_inet_connection_get_iobuf (GnomeVFSInetConnection *connection)
 {
@@ -106,3 +113,66 @@ gnome_vfs_inet_connection_get_iobuf (GnomeVFSInetConnection *connection)
 
 	return gnome_vfs_iobuf_new (connection->sock);
 }
+
+gint 
+gnome_vfs_inet_connection_get_fd (GnomeVFSInetConnection *connection)
+{
+	g_return_val_if_fail (connection != NULL, -1);
+	return connection->sock;
+}
+
+/* SocketImpl for InetConnections */
+
+static GnomeVFSResult 
+gnome_vfs_inet_connection_read (GnomeVFSInetConnection *connection,
+		                gpointer buffer,
+		                GnomeVFSFileSize bytes,
+		                GnomeVFSFileSize *bytes_read)
+{
+	gint read_val;
+
+	do {
+		read_val = read (connection->sock, buffer, bytes);
+	} while (read_val == -1 && errno == EINTR);
+
+	if (read_val == -1) {
+		*bytes_read = 0;
+		return gnome_vfs_result_from_errno ();
+	} else {
+		*bytes_read = read_val;
+	}
+	return GNOME_VFS_OK;
+}
+
+static GnomeVFSResult 
+gnome_vfs_inet_connection_write (GnomeVFSInetConnection *connection,
+			         gconstpointer buffer,
+			         GnomeVFSFileSize bytes,
+			         GnomeVFSFileSize *bytes_written)
+{
+	gint write_val;
+
+	do {
+		write_val = write (connection->sock, buffer, bytes);
+	} while (write_val == -1 && errno == EINTR);
+
+	if (write_val == -1) {
+		*bytes_written = 0;
+		return gnome_vfs_result_from_errno ();
+	} else {
+		*bytes_written = write_val;
+		return GNOME_VFS_OK;
+	}
+}
+
+static GnomeVFSSocketImpl inet_connection_socket_impl = {
+	(GnomeVFSSocketReadFunc)gnome_vfs_inet_connection_read,
+	(GnomeVFSSocketWriteFunc)gnome_vfs_inet_connection_write,
+	(GnomeVFSSocketCloseFunc)gnome_vfs_inet_connection_close
+};
+
+GnomeVFSSocket *
+gnome_vfs_inet_connection_to_socket (GnomeVFSInetConnection *connection)
+{
+	return gnome_vfs_socket_new (&inet_connection_socket_impl, connection);
+}
