@@ -36,11 +36,20 @@
 
 #include <config.h>
 
+#if GNOME_PLATFORM_VERSION < 1095000
 #include <gnome-xml/parser.h>
 #include <gnome-xml/tree.h>
 #include <gnome-xml/xmlmemory.h>
+#else
+#include <libxml/parser.h>
+#include <libxml/tree.h>
+#include <libxml/xmlmemory.h>
+#endif
+
+#if GNOME_PLATFORM_VERSION < 1095000
 #include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-util.h>
+#endif
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-private.h>
 #include <stdio.h>
@@ -569,7 +578,7 @@ vfs_module_init (const char *method_name, const char *args)
 	
 	if (load_settings (PREFIX "/etc/vfs/Test-conf.xml") == FALSE) {
 
-	  // FIXME: we probably shouldn't use printf to output the message
+	  /* FIXME: we probably shouldn't use printf to output the message */
 	  printf (_("Didn't find a valid settings file at %s\n"), 
 		  PREFIX "/etc/vfs/Test-conf.xml");
 	  properly_initialized = FALSE;
